@@ -16,10 +16,12 @@ namespace League\CommonMark\Tests\Functional\Extension\HeadingPermalink;
 use League\CommonMark\Environment\Environment;
 use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
 use League\CommonMark\Extension\HeadingPermalink\HeadingPermalinkExtension;
+use League\CommonMark\Extension\HeadingPermalink\HeadingPermalinkProcessor;
 use League\CommonMark\Extension\HeadingPermalink\HeadingPermalinkRenderer;
 use League\CommonMark\MarkdownConverter;
 use League\CommonMark\Parser\MarkdownParser;
 use League\CommonMark\Xml\XmlRenderer;
+use League\Config\Exception\InvalidConfigurationException;
 use PHPUnit\Framework\TestCase;
 
 final class HeadingPermalinkExtensionTest extends TestCase
@@ -38,7 +40,7 @@ final class HeadingPermalinkExtensionTest extends TestCase
         $this->assertEquals($expected, \trim((string) $converter->convert($input)));
     }
 
-    public function dataProviderForTestHeadingPermalinksWithDefaultOptions(): \Generator
+    public static function dataProviderForTestHeadingPermalinksWithDefaultOptions(): \Generator
     {
         yield ['# Hello World!', \sprintf('<h1><a id="content-hello-world" href="#content-hello-world" class="heading-permalink" aria-hidden="true" title="Permalink">%s</a>Hello World!</h1>', HeadingPermalinkRenderer::DEFAULT_SYMBOL)];
         yield ['# Hello *World*', \sprintf('<h1><a id="content-hello-world" href="#content-hello-world" class="heading-permalink" aria-hidden="true" title="Permalink">%s</a>Hello <em>World</em></h1>', HeadingPermalinkRenderer::DEFAULT_SYMBOL)];
@@ -59,7 +61,7 @@ final class HeadingPermalinkExtensionTest extends TestCase
                 'fragment_prefix' => 'custom-fragment-prefix',
                 // Ensure multiple characters are allowed (including multibyte) and special HTML characters are escaped.
                 'symbol'          => '¶ 🦄️ <3 You',
-                'insert'          => 'after',
+                'insert'          => HeadingPermalinkProcessor::INSERT_AFTER,
                 'title'           => 'Link',
                 'aria_hidden'     => false,
             ],
@@ -72,7 +74,7 @@ final class HeadingPermalinkExtensionTest extends TestCase
         $this->assertEquals($expected, \trim((string) $converter->convert($input)));
     }
 
-    public function dataProviderForTestHeadingPermalinksWithCustomOptions(): \Generator
+    public static function dataProviderForTestHeadingPermalinksWithCustomOptions(): \Generator
     {
         yield ['# Hello World!', '<h1>Hello World!<a id="custom-id-prefix-hello-world" href="#custom-fragment-prefix-hello-world" class="custom-class" title="Link">¶ 🦄️ &lt;3 You</a></h1>'];
         yield ['# Hello *World*', '<h1>Hello <em>World</em><a id="custom-id-prefix-hello-world" href="#custom-fragment-prefix-hello-world" class="custom-class" title="Link">¶ 🦄️ &lt;3 You</a></h1>'];
@@ -120,7 +122,7 @@ final class HeadingPermalinkExtensionTest extends TestCase
 
     public function testHeadingPermalinksWithInvalidInsertConfigurationValue(): void
     {
-        $this->expectException(\RuntimeException::class);
+        $this->expectException(InvalidConfigurationException::class);
 
         $environment = new Environment([
             'heading_permalink' => [
@@ -163,6 +165,63 @@ EOT;
         $this->assertEquals($expected, \trim((string) $converter->convert($input)));
     }
 
+    public function testHeadingPermalinksWithApplyIdToHeading(): void
+    {
+        $environment = new Environment([
+            'heading_permalink' => [
+                'apply_id_to_heading' => true,
+            ],
+        ]);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new HeadingPermalinkExtension());
+
+        $converter = new MarkdownConverter($environment);
+
+        $input    = '# Hello World!';
+        $expected = \sprintf('<h1 id="content-hello-world"><a href="#content-hello-world" class="heading-permalink" aria-hidden="true" title="Permalink">%s</a>Hello World!</h1>', HeadingPermalinkRenderer::DEFAULT_SYMBOL);
+
+        $this->assertEquals($expected, \trim((string) $converter->convert($input)));
+    }
+
+    public function testHeadingPermalinksWithApplyIdToHeadingAndClass(): void
+    {
+        $environment = new Environment([
+            'heading_permalink' => [
+                'apply_id_to_heading' => true,
+                'heading_class' => 'heading-anchor',
+            ],
+        ]);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new HeadingPermalinkExtension());
+
+        $converter = new MarkdownConverter($environment);
+
+        $input    = '# Hello World!';
+        $expected = \sprintf('<h1 id="content-hello-world" class="heading-anchor"><a href="#content-hello-world" class="heading-permalink" aria-hidden="true" title="Permalink">%s</a>Hello World!</h1>', HeadingPermalinkRenderer::DEFAULT_SYMBOL);
+
+        $this->assertEquals($expected, \trim((string) $converter->convert($input)));
+    }
+
+    public function testHeadingPermalinksWithApplyIdToHeadingWithoutLink(): void
+    {
+        $environment = new Environment([
+            'heading_permalink' => [
+                'insert' => HeadingPermalinkProcessor::INSERT_NONE,
+                'apply_id_to_heading' => true,
+                'heading_class' => 'heading-anchor',
+            ],
+        ]);
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addExtension(new HeadingPermalinkExtension());
+
+        $converter = new MarkdownConverter($environment);
+
+        $input    = '# Hello World!';
+        $expected = '<h1 id="content-hello-world" class="heading-anchor">Hello World!</h1>';
+
+        $this->assertEquals($expected, \trim((string) $converter->convert($input)));
+    }
+
     public function testXml(): void
     {
         $md = '# Hello *World*';
