@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /*
  * This file is part of the league/commonmark package.
  *
@@ -14,14 +16,15 @@
 
 namespace League\CommonMark\Tests\Unit;
 
-use League\CommonMark\Environment;
-use League\CommonMark\EnvironmentInterface;
+use League\CommonMark\Environment\Environment;
+use League\CommonMark\Environment\EnvironmentInterface;
+use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
 use League\CommonMark\MarkdownConverter;
 use PHPUnit\Framework\TestCase;
 
 final class MarkdownConverterTest extends TestCase
 {
-    public function testConstructorAndGetEnvironment()
+    public function testConstructorAndGetEnvironment(): void
     {
         $environment = $this->createMock(EnvironmentInterface::class);
 
@@ -30,14 +33,16 @@ final class MarkdownConverterTest extends TestCase
         $this->assertSame($environment, $converter->getEnvironment());
     }
 
-    public function testInvokeReturnsSameOutputAsConvertToHtml()
+    public function testInvokeReturnsSameOutputAsConvert(): void
     {
         $inputMarkdown = '**Strong**';
-        $expectedHtml = "<p><strong>Strong</strong></p>\n";
+        $expectedHtml  = "<p><strong>Strong</strong></p>\n";
 
-        $converter = new MarkdownConverter(Environment::createCommonMarkEnvironment());
+        $environment = new Environment();
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $converter = new MarkdownConverter($environment);
 
-        $this->assertSame($expectedHtml, $converter->convertToHtml($inputMarkdown));
-        $this->assertSame($expectedHtml, $converter($inputMarkdown));
+        $this->assertSame($expectedHtml, (string) $converter->convert($inputMarkdown));
+        $this->assertSame($expectedHtml, (string) $converter($inputMarkdown));
     }
 }
