@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /*
  * This file is part of the league/commonmark package.
  *
@@ -21,27 +23,6 @@ use League\CommonMark\Node\Node;
  */
 final class SimpleNode extends Node
 {
-    /**
-     * @var bool
-     */
-    private $container;
-
     /** @var mixed */
     public $value;
-
-    /**
-     * @param bool $isContainer
-     */
-    public function __construct(bool $isContainer = true)
-    {
-        $this->container = $isContainer;
-    }
-
-    /**
-     * @return bool
-     */
-    public function isContainer(): bool
-    {
-        return $this->container;
-    }
 }
